﻿using System;
using Xamarin.Forms;
using Syncfusion.SfChart.XForms;
using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Threading.Tasks;

namespace SimpleSample
{
	public class Doughnut : ContentPage
	{
		AbsoluteLayout layout;
		SfChart chart;
		ObservableCollection<ChartDataPoint> Data ;

		public Doughnut ()
		{
			
		   Data   = new ObservableCollection<ChartDataPoint>();
		   layout = new AbsoluteLayout(){Padding = new Thickness(5,15,5,5)};

			Data.Add(new ChartDataPoint("Jan", 23));
			Data.Add(new ChartDataPoint("Feb", 20));
			Data.Add(new ChartDataPoint("Mar", 35));
			Data.Add(new ChartDataPoint("Apr", 32));
			Data.Add(new ChartDataPoint("May", 45));
			Data.Add(new ChartDataPoint("Jun", 10));
			Data.Add(new ChartDataPoint("Jul", 20));

			chart = new SfChart ();

			var pie = new DoughnutSeries { 
				ItemsSource 			 = Data,
				ExplodeRadius			 = 15,
				EnableDataPointSelection = true,
				SelectedDataPointColor   = Color.FromRgb(245,125,0),
			};

			chart.VerticalOptions = LayoutOptions.FillAndExpand; 
			chart.Series.Add(pie);
			layout.Children.Add(chart);
			chart.ChartBehaviors.Add (new SelectionBehaviorExt (layout));
			Content = layout;
		} 
	}
		
	public class SelectionBehaviorExt : ChartSelectionBehavior
	{
		private AbsoluteLayout Layout;
		Label lbl;
		bool isVisible;
		public SelectionBehaviorExt( AbsoluteLayout layout)
		{
			Layout 				= layout;
			lbl  				= new Label ();
			lbl.BackgroundColor = Color.FromRgb(1,171,235);
			lbl.TextColor     	= Color.White;
			lbl.FontSize 		= 14;
			lbl.XAlign 			= TextAlignment.Center;
			lbl.YAlign 			= TextAlignment.Center;
		}
			
		public string XValue {
			get;
			set;
		}

		public double YValue {
			get;
			set;
		}

		// Displaying X Value and Y Value in Selection Behaviour
			
		protected override void OnSelectionChanged (ChartSelectionEventArgs arg)
		{
			base.OnSelectionChanged (arg);

			isVisible = true;

			if (arg.SelectedSeries != null)
			{
				ObservableCollection<ChartDataPoint> Data = (arg.SelectedSeries.ItemsSource as ObservableCollection<ChartDataPoint>);

				if (arg.SelectedDataPointIndex != -1)
				{
					(arg.SelectedSeries as PieSeries).ExplodeIndex = arg.SelectedDataPointIndex;
					XValue = Data[arg.SelectedDataPointIndex].XValue.ToString();
					YValue = Data[arg.SelectedDataPointIndex].YValue;
				}
				else
					isVisible = false;
			}
			else
				isVisible = false;

			Debug.WriteLine (arg.SelectedDataPointIndex);
		}

		protected override void OnTouchUp(float x, float y)
		{            
			base.OnTouchUp(x, y);     

			lbl.Text = " "+XValue +": "+YValue.ToString() +" ";

			if (isVisible )
				Layout.Children.Add (lbl, new Point (x, y));
			else
				Layout.Children.Remove (lbl);

			isVisible = false;
		}
	}

}
